package hu.bme.mit.books.swt;

import hu.bme.mit.books.manager.BookManager;
import hu.bme.mit.books.model.Book;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

public class BookComposite extends Composite {
	
	private BookManager manager;
	private int currentID;
	private Text titleText;
	private Text pagenumText;
	private Button isreadCheck;
	private Text authorText;
	private Button nextBookButton;
	private Button prevBookButton;

	public BookComposite(Composite parent, int style) {
		super(parent, style);
		initialize();
	}

	private void initialize() {
		setLayout(new GridLayout(2, true));
		Label authorLabel = new Label(this, SWT.NONE);
		authorLabel.setText("Author:");
		authorText = new Text(this, SWT.NONE);
		
		Label titleLabel = new Label(this, SWT.NONE);
		titleLabel.setText("Title:");
		titleText = new Text(this, SWT.NONE);
		
		Label pagenumLabel = new Label(this, SWT.NONE);
		pagenumLabel.setText("Number of pages:");
		pagenumText = new Text(this, SWT.NONE);
		
		isreadCheck = new Button(this, SWT.CHECK);
		isreadCheck.setText("Read");
		GridData twoColData = new GridData();
		twoColData.horizontalSpan = 2;
		isreadCheck.setLayoutData(twoColData);
		
		prevBookButton = new Button(this, SWT.NONE);
		prevBookButton.setText("Previous book");
		prevBookButton.setEnabled(false);
		prevBookButton.addSelectionListener(new SelectionAdapter() {

			@Override
			public void widgetSelected(SelectionEvent e) {
				currentID--;
				refreshBookData();
			}
			
		});
		nextBookButton = new Button(this, SWT.NONE);
		nextBookButton.setText("Next book");
		nextBookButton.setEnabled(false);
		nextBookButton.addSelectionListener(new SelectionAdapter() {

			@Override
			public void widgetSelected(SelectionEvent e) {
				currentID++;
				refreshBookData();
			}
			
		});
	}

	public void setBookManager(BookManager manager){
		this.manager = manager;
		this.currentID = 0;
		refreshBookData();
	}

	private void refreshBookData() {
		Book book = manager.getBookOfID(currentID);
		titleText.setText(book.getTitle());
		authorText.setText(book.getAuthor());
		pagenumText.setText(Integer.toString(book.getPageNum()));
		isreadCheck.setSelection(book.isRead());
		prevBookButton.setEnabled(currentID > 0);
		nextBookButton.setEnabled(currentID < manager.getNumberOfBooks() - 1);
	}
}

